[jbpm-commits] JBoss JBPM SVN: r4566 - in projects/gwt-console/branches/hbraun: plugin-api/src/main/java/org/jboss/bpm/console/client and 7 other directories.

do-not-reply at jboss.org do-not-reply at jboss.org
Thu Apr 16 09:31:50 EDT 2009


Author: heiko.braun at jboss.com
Date: 2009-04-16 09:31:50 -0400 (Thu, 16 Apr 2009)
New Revision: 4566

Added:
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainLayout.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/DefinitionListView.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/LoadDefinitionsAction.java
Removed:
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/process/
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/report/
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/task/
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainView.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainViewAction.java
Modified:
   projects/gwt-console/branches/hbraun/plugin-api/pom.xml
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/ApplicationContext.java
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Editor.java
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Menu.java
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/View.java
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Workspace.java
   projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/model/DTOParser.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/Header.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/MainView.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/LoginView.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditor.java
   projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditorNavigation.java
   projects/gwt-console/branches/hbraun/war/src/main/resources/mvc4g-conf.xml
   projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/public/console.css
   projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/workspace-default.cfg
Log:
Remove legacy code. Implement ProcessEditor list view

Modified: projects/gwt-console/branches/hbraun/plugin-api/pom.xml
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/pom.xml	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/pom.xml	2009-04-16 13:31:50 UTC (rev 4566)
@@ -66,7 +66,24 @@
       <artifactId>gwt-mosaic-gwtx</artifactId>
     </dependency>
 
+    <dependency>
+      <groupId>com.googlecode.mvc4g</groupId>
+      <artifactId>mvc4g</artifactId>
+    </dependency>
 
+    <!-- 3rd party -->
+
+    <dependency>
+      <groupId>commons-lang</groupId>
+      <artifactId>commons-lang</artifactId>
+    </dependency>
+
+    <dependency>
+      <groupId>commons-configuration</groupId>
+      <artifactId>commons-configuration</artifactId>
+    </dependency>
+
+
   </dependencies>
 
   <build>

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/ApplicationContext.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/ApplicationContext.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/ApplicationContext.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -21,10 +21,10 @@
  */
 package org.jboss.bpm.console.client;
 
-import com.gwtext.client.widgets.Viewport;
+import com.mvc4g.client.Controller;
 
 /**
- * Provides context information to console compoments and plugins.
+ * Provides context information to console components and plugins.
  * 
  * @author Heiko.Braun <heiko.braun at jboss.com>
  */
@@ -39,5 +39,7 @@
   Authentication getAuthentication();
 
   ConsoleConfig getConfig();
- 
+
+  Controller getController();
+
 }

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Editor.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Editor.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Editor.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -21,27 +21,36 @@
  */
 package org.jboss.bpm.console.client;
 
-import com.gwtext.client.widgets.Panel;
+import com.mvc4g.client.Controller;
+import org.gwt.mosaic.ui.client.layout.LayoutPanel;
+import org.gwt.mosaic.ui.client.layout.BorderLayout;
 
-import java.util.List;
-import java.util.ArrayList;
 
 /**
- * An editor can be plugged into a {@link org.jboss.bpm.console.client.Workspace}
- *
+ * An editor can be plugged into a {@link org.jboss.bpm.console.client.Workspace}.
+ * and aggregates {@link org.jboss.bpm.console.client.View}'s.<br>
+ * View's are maintained through a {@link com.mvc4g.client.Controller}.
+ * <p/>
+ * Editor's can communicate though a hirarchical controller chain.
+ * <p/>
+ * Each Editor uses a {@link org.gwt.mosaic.ui.client.layout.BorderLayout} by default.
+ * 
  * @author Heiko.Braun <heiko.braun at jboss.com>
  */
-public abstract class Editor extends Panel
+public abstract class Editor extends LayoutPanel
 {
   protected ApplicationContext appContext;
-  protected List<String> managedTabs;
 
-  public Editor(ApplicationContext applicationContext)
+  protected Controller controller;
+
+  public Editor(ApplicationContext appContext)
   {
-    super();
-    this.appContext = applicationContext;
-    this.managedTabs = new ArrayList<String>();
-    this.setPaddings(10);
+    super( new BorderLayout() );
+    this.appContext = appContext;
+
+    // hmvc controller chain.
+    this.controller = new Controller();
+    this.controller.setParent(appContext.getController());
   }
 
   public abstract String getEditorId();
@@ -49,19 +58,22 @@
   public abstract String getTitle();
 
   public abstract String getIconCSS();
+  
+  public abstract MenuSection provideMenuSection();  
 
-  public abstract MenuSection provideMenuSection();
-
+  @Deprecated
   public boolean hasView(String viewId)
   {
     return false;
   }
 
+  @Deprecated
   public void showView(String viewId)
   {
     appContext.getWorkpace().showEditor(viewId);
   }
 
+  @Deprecated
   public void addView(View view, boolean closable)
   {
     /*String tabId = view.getViewId() + ".tab";
@@ -75,17 +87,6 @@
     appContext.getWorkpace().setActiveTab(view.getId());*/
 
     System.out.println("*** addView should be re-implemented ***");
-
-    managedTabs.add(view.getId());
-
+    
   }
-
-  class WrapperPanel extends Panel
-  {
-    public WrapperPanel(String id)
-    {
-      super();
-      setId(id);
-    }
-  }
 }

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Menu.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Menu.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Menu.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -26,6 +26,8 @@
 import org.gwt.mosaic.ui.client.layout.BoxLayout;
 import org.gwt.mosaic.ui.client.layout.BoxLayoutData;
 import org.gwt.mosaic.ui.client.layout.LayoutPanel;
+import com.mvc4g.client.ViewInterface;
+import com.mvc4g.client.Controller;
 
 /**
  * The main menu on the left hand.
@@ -33,15 +35,14 @@
  *
  * @author Heiko.Braun <heiko.braun at jboss.com>
  */
-public class Menu extends LayoutPanel
-{
-  private final ApplicationContext appContext;
+public class Menu extends LayoutPanel implements ViewInterface
+{  
   private StackLayoutPanel stack;  
+  private Controller controller;
 
-  public Menu(final ApplicationContext appContext)
+  public Menu()
   {
     super(new BoxLayout(BoxLayout.Orientation.VERTICAL));
-    this.appContext = appContext;
 
     this.setWidgetSpacing(5);
 
@@ -55,4 +56,8 @@
     this.stack.add(menuSection, menuSection.getMenuTitle());
   }
 
+  public void setController(Controller controller)
+  {
+    this.controller = controller;
+  }
 }

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/View.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/View.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/View.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -22,17 +22,21 @@
 package org.jboss.bpm.console.client;
 
 import com.gwtext.client.widgets.Panel;
+import com.mvc4g.client.ViewInterface;
+import com.mvc4g.client.Controller;
 
 /**
  * View's are {@link org.jboss.bpm.console.client.Editor} components
  *
  * @author Heiko.Braun <heiko.braun at jboss.com>
  */
-public abstract class View extends Panel
+public abstract class View extends Panel implements ViewInterface
 {
 
   protected ApplicationContext mainMenu;
 
+  protected Controller controller;
+
   protected View(ApplicationContext main)
   {
     super();
@@ -43,4 +47,10 @@
   public abstract String getViewId();
 
   public abstract String getIconCSS();
+
+
+  public void setController(Controller controller)
+  {
+    this.controller = controller;
+  }
 }

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Workspace.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Workspace.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/Workspace.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -23,6 +23,8 @@
 
 import org.gwt.mosaic.ui.client.DeckLayoutPanel;
 import org.gwt.mosaic.ui.client.layout.LayoutPanel;
+import com.mvc4g.client.ActionInterface;
+import com.mvc4g.client.Controller;
 
 /**
  * Maintains {@link Editor}'s
@@ -31,22 +33,15 @@
  */
 public class Workspace extends DeckLayoutPanel
 {
-  protected ApplicationContext view;
+  protected ApplicationContext appContext;
   private Menu menu;
-  
+
   public Workspace(Menu menu)
   {
     super();
     this.menu = menu;
     this.setPadding(5);
-    
-  }
 
-  private EditorDeck createDeck(Editor editor)
-  {
-    EditorDeck deck = new EditorDeck(editor);
-    deck.add(editor);
-    return deck;
   }
 
   public void addEditor(Editor editor, boolean closeable)
@@ -56,7 +51,7 @@
 
     // Editor deck
     EditorDeck deck = createDeck(editor);
-    deck.index = this.getWidgetCount();    
+    deck.index = this.getWidgetCount();
     this.add(deck);
   }
 
@@ -69,10 +64,17 @@
   {
     EditorDeck deck = findEditor(id);
     if(null==deck)
-      throw new IllegalArgumentException("No such editor: " +id);       
+      throw new IllegalArgumentException("No such editor: " +id);
     this.showWidget(deck.index);
   }
 
+  private EditorDeck createDeck(Editor editor)
+  {
+    EditorDeck deck = new EditorDeck(editor);
+    deck.add(editor);
+    return deck;
+  }
+
   private EditorDeck findEditor(String id)
   {
     EditorDeck match = null;
@@ -85,7 +87,7 @@
         break;
       }
     }
- 
+
     return match;
   }
 

Modified: projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/model/DTOParser.java
===================================================================
--- projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/model/DTOParser.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/plugin-api/src/main/java/org/jboss/bpm/console/client/model/DTOParser.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -21,15 +21,15 @@
  */
 package org.jboss.bpm.console.client.model;
 
+import com.google.gwt.core.client.JavaScriptObject;
 import com.google.gwt.json.client.*;
+import org.jboss.bpm.console.client.model.jbpm3.TokenReference;
 import org.jboss.bpm.console.client.util.ConsoleLog;
-import org.jboss.bpm.console.client.model.jbpm3.TokenReference;
 import org.jboss.bpm.console.client.util.JSONWalk;
 
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
-import java.util.Map;
 
 /**
  * TODO: run integrated (gwt-console-server) test
@@ -38,9 +38,20 @@
  */
 public class DTOParser
 {
-  public static ProcessDefinitionRef parseProcessDefinition(String json)
+  public static List<ProcessDefinitionRef> parseProcessDefinitions(JavaScriptObject jso)
   {
-    JSONValue root = JSONParser.parse(json);
+    List<ProcessDefinitionRef> results = new ArrayList<ProcessDefinitionRef>();
+      
+    JSONArray arr = JSONWalk.on( new JSONObject(jso)).next("definitions").asArray();
+    for(int i=0; i<arr.size(); i++)
+    {
+      results.add(parseProcessDefinition(arr.get(i)));  
+    }
+    return results;
+  }
+
+  public static ProcessDefinitionRef parseProcessDefinition(JSONValue root)
+  {
     String id = JSONWalk.on(root).next("id").asString();
     Long version = JSONWalk.on(root).next("version").asLong();
     String name = JSONWalk.on(root).next("name").asString();
@@ -48,6 +59,12 @@
     return new ProcessDefinitionRef(id, name, version);
   }
 
+  public static ProcessDefinitionRef parseProcessDefinition(String json)
+  {
+    JSONValue root = JSONParser.parse(json);
+    return parseProcessDefinition(root);
+  }
+
   public static List<String> parseRolesAssigned(String json)
   {
     // parse roles

Modified: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/Header.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/Header.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/Header.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -22,15 +22,18 @@
 package org.jboss.bpm.console.client;
 
 import com.google.gwt.user.client.ui.*;
+import com.mvc4g.client.Controller;
+import com.mvc4g.client.ViewInterface;
 
 import java.util.List;
 
 /**
  * @author Heiko.Braun <heiko.braun at jboss.com>
  */
-public class Header extends HorizontalPanel
+public class Header extends HorizontalPanel implements ViewInterface
 {
   private ApplicationContext appContext;
+  private Controller controller;
 
   public final static String ID = "org.jboss.bpm.headerPanel";
 
@@ -72,4 +75,10 @@
     this.add(p);
         
   }
+
+
+  public void setController(Controller controller)
+  {
+    this.controller = controller;
+  }
 }

Modified: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/MainView.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/MainView.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/MainView.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -25,6 +25,7 @@
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.HTML;
 import com.google.gwt.user.client.ui.RootPanel;
+import com.mvc4g.client.Controller;
 import org.gwt.mosaic.ui.client.MessageBox;
 import org.gwt.mosaic.ui.client.Viewport;
 import org.gwt.mosaic.ui.client.layout.BorderLayout;
@@ -65,6 +66,12 @@
     RootPanel.get().add(viewport);
   }
 
+
+  public Controller getController()
+  {
+    throw new RuntimeException("NYI");
+  }
+
   private LayoutPanel createLayout()
   {
     final LayoutPanel layoutPanel = new LayoutPanel(new BorderLayout());
@@ -74,16 +81,13 @@
     layoutPanel.add(header, new BorderLayoutData(Region.NORTH, 50));
 
     // menu
-    menu = new Menu(this);
+    menu = new Menu();
     layoutPanel.add(menu, new BorderLayoutData(Region.WEST, 200));
 
     // workspace
     workspace = createWorkspace(layoutPanel);
     layoutPanel.add(workspace, new BorderLayoutData(Region.CENTER, false));
     
-    //layoutPanel.add(b2, new BorderLayoutData(Region.SOUTH, 10, 200));
-    //layoutPanel.add(b3, new BorderLayoutData(Region.EAST, 10, 200));
-
     return layoutPanel;
   }
 

Modified: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/LoginView.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainLayout.java	                        (rev 0)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainLayout.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -0,0 +1,147 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2006, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.bpm.console.client.v2;
+
+import com.google.gwt.core.client.GWT;
+import com.google.gwt.user.client.ui.Composite;
+import com.google.gwt.user.client.ui.HTML;
+import com.google.gwt.user.client.ui.RootPanel;
+import com.mvc4g.client.Controller;
+import org.gwt.mosaic.ui.client.MessageBox;
+import org.gwt.mosaic.ui.client.Viewport;
+import org.gwt.mosaic.ui.client.InfoPanel;
+import org.gwt.mosaic.ui.client.layout.BorderLayout;
+import static org.gwt.mosaic.ui.client.layout.BorderLayout.Region;
+import org.gwt.mosaic.ui.client.layout.BorderLayoutData;
+import org.gwt.mosaic.ui.client.layout.LayoutPanel;
+import org.jboss.bpm.console.client.*;
+
+/**
+ * The main composite that assembles the gwt console application.
+ *
+ * @author Heiko.Braun <heiko.braun at jboss.com>
+ */
+public class MainLayout extends Composite implements ApplicationContext
+{
+  
+  public final static String NAME = "mainLayout";
+
+  private HTML status = new HTML();
+  private Header header;
+  private Menu menu;
+  private Workspace workspace;
+
+  private URLBuilder urlBuilder;
+  private Authentication auth;
+
+  private ConsoleConfig config;
+
+  private Controller controller;
+  
+  public MainLayout(Controller controller, Authentication auth, URLBuilder urlBuilder, ConsoleConfig config)
+  {
+    this.controller = controller;   
+    this.auth = auth;
+    this.config = config;
+    this.urlBuilder = urlBuilder;
+
+    display();
+  }
+
+  public void display()
+  {    
+    Viewport viewport = new Viewport();
+
+    LayoutPanel layout = createLayout();
+    viewport.add(layout);
+
+    RootPanel.get().add(viewport);
+  }
+
+  private LayoutPanel createLayout()
+  {
+    final LayoutPanel layoutPanel = new LayoutPanel(new BorderLayout());
+
+    // header
+    header = new Header(this, auth.getUsername(), auth.getRolesAssigned());
+    layoutPanel.add(header, new BorderLayoutData(Region.NORTH, 50));
+
+    // menu
+    menu = new Menu();
+    layoutPanel.add(menu, new BorderLayoutData(Region.WEST, 200));
+
+    // workspace
+    workspace = createWorkspace();
+    layoutPanel.add(workspace, new BorderLayoutData(Region.CENTER, false));
+
+    return layoutPanel;
+  }
+
+  private Workspace createWorkspace()
+  {
+    Workspace workspace = new Workspace(menu);
+    WorkspaceLauncher launcher = GWT.create(WorkspaceLauncher.class);
+    launcher.launch(this, workspace);    // calls Workspace.addEditor()
+    return workspace;
+  }
+
+  // ---- ApplicationContext interface ----
+
+
+  public Controller getController()
+  {
+    return this.controller;
+  }
+
+  public URLBuilder getUrlBuilder()
+  {
+    return this.urlBuilder;
+  }
+
+  public void displayMessage(final String message, final boolean isError)
+  {
+    status.setText(message);
+
+    if(isError)
+      MessageBox.error("Error", message);
+    else
+    {
+      InfoPanel.show("", message, "");
+    }
+  }
+
+  public Authentication getAuthentication()
+  {
+    return auth;
+  }
+
+  public ConsoleConfig getConfig()
+  {
+    return config;
+  }
+
+  public Workspace getWorkpace()
+  {
+    return workspace;
+  }
+}
+

Deleted: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainView.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainView.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainView.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -1,213 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2006, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.bpm.console.client.v2;
-
-import com.google.gwt.core.client.GWT;
-import com.google.gwt.user.client.ui.Composite;
-import com.google.gwt.user.client.ui.HTML;
-import com.google.gwt.user.client.ui.RootPanel;
-import com.mvc4g.client.ViewInterface;
-import com.mvc4g.client.Controller;
-import org.gwt.mosaic.ui.client.MessageBox;
-import org.gwt.mosaic.ui.client.Viewport;
-import org.gwt.mosaic.ui.client.layout.BorderLayout;
-import static org.gwt.mosaic.ui.client.layout.BorderLayout.Region;
-import org.gwt.mosaic.ui.client.layout.BorderLayoutData;
-import org.gwt.mosaic.ui.client.layout.LayoutPanel;
-import org.jboss.bpm.console.client.util.ConsoleLog;
-import org.jboss.bpm.console.client.*;
-
-/**
- * The main composite that assembles the gwt console application.
- *
- * @author Heiko.Braun <heiko.braun at jboss.com>
- */
-public class MainView extends Composite implements ApplicationContext, ViewInterface
-{
-  
-  public final static String NAME = "mainView";
-
-  private HTML status = new HTML();
-  private Header header;
-  private Menu menu;
-  private Workspace workspace;
-
-  private URLBuilder urlBuilder;
-  private Authentication auth;
-
-  private ConsoleConfig config;
-
-  private Controller controller;
-
-  private boolean isInitialized;
-
-  public void init(Authentication auth, URLBuilder urlBuilder, ConsoleConfig config)
-  {
-    this.auth = auth;
-    this.config = config;
-    this.urlBuilder = urlBuilder;
-
-    isInitialized = true;
-  }
-
-  public void display()
-  {
-    if(!isInitialized)
-      throw new IllegalStateException("Not initalized");
-    
-    Viewport viewport = new Viewport();
-
-    LayoutPanel layout = createLayout();
-    viewport.add(layout);
-
-    RootPanel.get().add(viewport);
-  }
-  
-  public void setController(Controller controller)
-  {
-    this.controller = controller;
-  }
-
-  private LayoutPanel createLayout()
-  {
-    final LayoutPanel layoutPanel = new LayoutPanel(new BorderLayout());
-
-    // header
-    header = new Header(this, auth.getUsername(), auth.getRolesAssigned());
-    layoutPanel.add(header, new BorderLayoutData(Region.NORTH, 50));
-
-    // menu
-    menu = new Menu(this);
-    layoutPanel.add(menu, new BorderLayoutData(Region.WEST, 200));
-
-    // workspace
-    workspace = createWorkspace(layoutPanel);
-    layoutPanel.add(workspace, new BorderLayoutData(Region.CENTER, false));
-
-    //layoutPanel.add(b2, new BorderLayoutData(Region.SOUTH, 10, 200));
-    //layoutPanel.add(b3, new BorderLayoutData(Region.EAST, 10, 200));
-
-    return layoutPanel;
-  }
-
-  private Workspace createWorkspace(LayoutPanel layoutPanel)
-  {
-    Workspace workspace = new Workspace(menu);
-    WorkspaceLauncher launcher = GWT.create(WorkspaceLauncher.class);
-    launcher.launch(this, workspace);
-    return workspace;
-  }
-
-  /*private Panel createMainPanel()
-  {
-    Panel mainPanel = new Panel();
-    mainPanel.setBorder(false);
-    mainPanel.setPaddings(5); // outer most padding
-    mainPanel.setLayout(new FitLayout());
-    mainPanel.setWidth(UIConstants.OVERALL_WIDTH);
-    mainPanel.setHeight(UIConstants.OVERALL_WIDTH);
-    mainPanel.setAutoWidth(false);
-    return mainPanel;
-  }
-
-  private void assembleMainApplication(Panel mainPanel)
-  {
-    Panel borderPanel = new Panel();
-    borderPanel.setBorder(false);
-    borderPanel.setLayout(new BorderLayout());
-
-    // ------------------------------------------
-
-    header = new Header(this);
-    borderPanel.add(header, new BorderLayoutData(RegionPosition.NORTH));
-    header.setUserInfo(auth.getUsername(), auth.getRolesAssigned());
-
-    // ------------------------------------------
-
-    menu = new Menu(this);
-    BorderLayoutData menuData = new BorderLayoutData(RegionPosition.WEST);
-    menuData.setSplit(false);
-    menuData.setMinSize(UIConstants.MAIN_MENU_MIN);
-    menuData.setMaxSize(UIConstants.MAIN_MENU_MAX);
-    menuData.setMargins(new Margins(0, 5, 0, 0));
-    borderPanel.add(menu, menuData);
-
-    // ------------------------------------------
-
-    workspace = new Workspace(menu);
-    WorkspaceLauncher launcher = GWT.create(WorkspaceLauncher.class);
-    launcher.launch(this, workspace);
-
-    borderPanel.add(workspace, new BorderLayoutData(RegionPosition.CENTER));
-
-    // ------------------------------------------
-
-    mainPanel.add(borderPanel);
-  }  */
-
-  public void addEditor(Editor editor)
-  {
-    ConsoleLog.debug("Add editor " + editor.getEditorId());
-    workspace.addEditor(editor, true);
-  }
-
-  public boolean hasEditor(String id)
-  {
-    return workspace.hasEditor(id);
-  }
-
-  public void showEditor(String id)
-  {
-    workspace.showEditor(id);
-  }
-
-  public URLBuilder getUrlBuilder()
-  {
-    return this.urlBuilder;
-  }
-
-  public void displayMessage(final String message, final boolean isError)
-  {
-    status.setText(message);
-
-    if(isError)
-      MessageBox.error("Error", message);
-    else
-      MessageBox.alert("Alert", message);
-  }
-
-  public Authentication getAuthentication()
-  {
-    return auth;
-  }
-
-  public ConsoleConfig getConfig()
-  {
-    return config;
-  }
-
-  public Workspace getWorkpace()
-  {
-    return workspace;
-  }
-}
-

Deleted: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainViewAction.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainViewAction.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainViewAction.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -1,45 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2006, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.bpm.console.client.v2;
-
-import com.mvc4g.client.ActionInterface;
-import com.mvc4g.client.Controller;
-import org.jboss.bpm.console.client.v2.events.BootstrapEvent;
-
-/**
- * @author Heiko.Braun <heiko.braun at jboss.com>
- */
-public class MainViewAction implements ActionInterface
-{
-  public void execute(Controller controller, Object object)
-  {
-    BootstrapEvent bootstrap = (BootstrapEvent)object;
-    MainView mainView = (MainView)controller.getView(MainView.NAME);
-    mainView.init(
-        bootstrap.getAuth(),
-        bootstrap.getUrlBuilder(),
-        bootstrap.getConfig()
-    );
-
-    mainView.display();
-  }
-}

Added: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/DefinitionListView.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/DefinitionListView.java	                        (rev 0)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/DefinitionListView.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -0,0 +1,157 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2006, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.bpm.console.client.v2.process;
+
+import com.google.gwt.user.client.ui.ClickListener;
+import com.google.gwt.user.client.ui.Widget;
+import com.google.gwt.user.client.ui.ChangeListener;
+import com.google.gwt.user.client.ui.FocusListener;
+import com.google.gwt.user.client.Window;
+import com.mvc4g.client.Controller;
+import com.mvc4g.client.ViewInterface;
+import com.mvc4g.client.Event;
+import org.gwt.mosaic.ui.client.*;
+import org.gwt.mosaic.ui.client.layout.BoxLayout;
+import org.gwt.mosaic.ui.client.layout.BoxLayoutData;
+import org.gwt.mosaic.ui.client.layout.LayoutPanel;
+import org.gwt.mosaic.ui.client.layout.FillLayoutData;
+import org.gwt.mosaic.ui.client.list.DefaultListModel;
+import org.jboss.bpm.console.client.model.ProcessDefinitionRef;
+
+import java.util.List;
+
+/**
+ * @author Heiko.Braun <heiko.braun at jboss.com>
+ */
+public class DefinitionListView extends LayoutPanel implements ViewInterface
+{
+  private Controller controller;
+
+  private LayoutPanel table = null;
+
+  public final static String ID = DefinitionListView.class.getName();
+
+  public DefinitionListView()
+  {
+    super();
+    setTitle("Process Definitions");
+  }
+
+  public void setController(Controller controller)
+  {
+    this.controller = controller;
+  }
+
+  private LayoutPanel createTable(List<ProcessDefinitionRef> definitions)
+  {
+    final LayoutPanel vBox = new LayoutPanel( new BoxLayout(BoxLayout.Orientation.VERTICAL));
+    vBox.setPadding(0);
+    vBox.setWidgetSpacing(0);
+
+    final ListBox<ProcessDefinitionRef> listBox =
+        new ListBox<ProcessDefinitionRef>(
+            new String[] {
+                "Process ID", "Name", "Key", "Version"}
+        );
+
+    
+    listBox.setCellRenderer(new ListBox.CellRenderer<ProcessDefinitionRef>() {
+      public void renderCell(ListBox<ProcessDefinitionRef> listBox, int row, int column,
+                             ProcessDefinitionRef item) {
+        switch (column) {
+          case 0:
+            listBox.setText(row, column, item.getId());
+            break;
+          case 1:
+            listBox.setText(row, column, item.getName());
+            break;
+          case 2:
+            listBox.setText(row, column, item.getKey());
+            break;
+          case 3:
+            listBox.setText(row, column, String.valueOf(item.getVersion()));
+            break;
+          default:
+            throw new RuntimeException("Unexpected column size");
+        }
+      }
+    });
+
+    final DefaultListModel<ProcessDefinitionRef> model =
+        (DefaultListModel<ProcessDefinitionRef>) listBox.getModel();
+
+    for(ProcessDefinitionRef def : definitions)
+    {
+      model.add(def);
+    }    
+    
+    // toolbar
+
+    final LayoutPanel toolBox = new LayoutPanel();
+    toolBox.setPadding(0);
+    toolBox.setWidgetSpacing(5);
+    //toolBox.setLayout(new BoxLayout(BoxLayout.Orientation.VERTICAL));
+
+    final ToolBar toolBar = new ToolBar();
+    toolBar.add(
+        new ToolButton("Refresh", new ClickListener() {
+          public void onClick(Widget sender) {
+            // force loading
+            controller.handleEvent(
+                new Event(LoadDefinitionsAction.ID, null)
+            );
+          }
+        }
+        )
+    );
+
+    toolBar.addSeparator();
+
+    toolBar.add(
+        new ToolButton("Test", new ClickListener() {
+          public void onClick(Widget sender) {
+            System.out.println(listBox.getSelectedIndex());
+          }
+        }
+        )
+    );
+
+    toolBox.add(toolBar, new BoxLayoutData(BoxLayoutData.FillStyle.HORIZONTAL));
+
+    vBox.add(toolBox, new BoxLayoutData(BoxLayoutData.FillStyle.HORIZONTAL));
+    vBox.add(listBox, new BoxLayoutData(BoxLayoutData.FillStyle.BOTH));
+
+    return vBox;
+  }
+
+  public void update(List<ProcessDefinitionRef> definitions)
+  {
+    if(this.table!=null)
+      this.remove(table);
+
+    this.table = createTable(definitions);
+    this.add(table);
+
+    // layout again
+    this.invalidate();
+  }
+}

Added: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/LoadDefinitionsAction.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/LoadDefinitionsAction.java	                        (rev 0)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/LoadDefinitionsAction.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -0,0 +1,85 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2006, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.bpm.console.client.v2.process;
+
+import com.google.gwt.core.client.JavaScriptObject;
+import com.mvc4g.client.ActionInterface;
+import com.mvc4g.client.Controller;
+import org.jboss.bpm.console.client.ApplicationContext;
+import org.jboss.bpm.console.client.model.DTOParser;
+import org.jboss.bpm.console.client.model.ProcessDefinitionRef;
+import org.jboss.bpm.console.client.util.JSONRequest;
+import org.jboss.bpm.console.client.util.JSONRequestHandler;
+
+import java.util.List;
+
+/**
+ * Fire's a new event when definitions are loaded.
+ *
+ * @author Heiko.Braun <heiko.braun at jboss.com>
+ */
+public class LoadDefinitionsAction implements ActionInterface
+{
+  public final static String ID = LoadDefinitionsAction.class.getName();
+
+  ApplicationContext appContext;
+
+  public LoadDefinitionsAction(ApplicationContext appContext)
+  {
+    this.appContext = appContext;
+  }
+
+  public void execute(final Controller controller, Object object)
+  {
+    String url = appContext.getUrlBuilder().getProcessDefinitionsURL();
+    
+    JSONRequest.get(
+        url, new JSONRequestHandler()
+    {
+      public void onRequestComplete(JavaScriptObject json)
+      {
+        if (json == null) {
+          appContext.displayMessage("Couldn't retrieve process definition data", true);
+          return;
+        }
+
+        List<ProcessDefinitionRef> definitions = null;
+        try
+        {
+          definitions = DTOParser.parseProcessDefinitions(json);
+        }
+        catch (Throwable e)
+        {
+          e.printStackTrace();
+          appContext.displayMessage(e.getMessage(), true);
+        }
+        
+
+        DefinitionListView view = (DefinitionListView) controller.getView(DefinitionListView.ID);
+        view.update(definitions);
+
+        appContext.displayMessage("Loaded " + definitions.size() + " process definitions", false);
+      }
+    }
+    );
+  }
+}

Modified: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditor.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditor.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditor.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -21,6 +21,14 @@
  */
 package org.jboss.bpm.console.client.v2.process;
 
+import com.google.gwt.user.client.ui.Widget;
+import com.mvc4g.client.ActionInterface;
+import com.mvc4g.client.Event;
+import com.mvc4g.client.ViewInterface;
+import org.gwt.mosaic.ui.client.DecoratedTabLayoutPanel;
+import org.gwt.mosaic.ui.client.TabLayoutPanel;
+import static org.gwt.mosaic.ui.client.layout.BorderLayout.Region;
+import org.gwt.mosaic.ui.client.layout.BorderLayoutData;
 import org.jboss.bpm.console.client.ApplicationContext;
 import org.jboss.bpm.console.client.Editor;
 import org.jboss.bpm.console.client.MenuSection;
@@ -30,13 +38,47 @@
  */
 public class ProcessEditor extends Editor
 {
-  public final static String ID = "org.jboss.bpm.process.ProcessEditor";
+  public final static String ID = ProcessEditor.class.getName();
 
-  public ProcessEditor(ApplicationContext applicationContext)
+  private TabLayoutPanel tabPanel;
+
+  public ProcessEditor(ApplicationContext appContext)
   {
-    super(applicationContext);
+    super(appContext);
+
+    // create inner tab layout
+    this.tabPanel = new DecoratedTabLayoutPanel();
+    tabPanel.setPadding(5);
+    this.add(tabPanel, new BorderLayoutData(Region.CENTER, false));
+
+    // create and register views
+    addView(DefinitionListView.ID, new DefinitionListView());
+
+    // create and register actions
+    addAction(LoadDefinitionsAction.ID, new LoadDefinitionsAction(appContext));
+
+    // force loading
+    super.controller.handleEvent(
+        new Event(LoadDefinitionsAction.ID, null)
+    );
+
+    tabPanel.selectTab(0);
   }
 
+  private void addView(String id, Widget view)
+  {
+    // register view with controller
+    super.controller.addView(id, (ViewInterface)view);
+
+    // add to tab layout
+    this.tabPanel.add(view, view.getTitle());
+  }
+
+  private void addAction(String name, ActionInterface action)
+  {
+    super.controller.addAction(name, action);  
+  }
+
   public String getEditorId()
   {
     return ID;

Modified: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditorNavigation.java
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditorNavigation.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/process/ProcessEditorNavigation.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -24,9 +24,8 @@
 import com.google.gwt.user.client.ui.Tree;
 import com.google.gwt.user.client.ui.TreeItem;
 import com.google.gwt.user.client.ui.TreeListener;
-import org.jboss.bpm.console.client.Workspace;
 import org.jboss.bpm.console.client.ApplicationContext;
-import org.jboss.bpm.console.client.process.ProcessEditor;
+import org.jboss.bpm.console.client.Workspace;
 
 /**
  * @author Heiko.Braun <heiko.braun at jboss.com>

Modified: projects/gwt-console/branches/hbraun/war/src/main/resources/mvc4g-conf.xml
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/resources/mvc4g-conf.xml	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/resources/mvc4g-conf.xml	2009-04-16 13:31:50 UTC (rev 4566)
@@ -8,11 +8,9 @@
   <controller name="mainController" class="com.mvc4g.client.Controller">
     <views>
       <view name="loginView" class="org.jboss.bpm.console.client.v2.LoginView" />
-      <view name="mainView" class="org.jboss.bpm.console.client.v2.MainView" />
     </views>
     <actions>
-      <action name="login" class="org.jboss.bpm.console.client.v2.LoginAction" />
-      <action name="loginSuccessful" class="org.jboss.bpm.console.client.v2.MainViewAction" />
+      <action name="login" class="org.jboss.bpm.console.client.v2.LoginAction" />      
     </actions>
   </controller>
 

Modified: projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/public/console.css
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/public/console.css	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/public/console.css	2009-04-16 13:31:50 UTC (rev 4566)
@@ -14,6 +14,11 @@
   width:150px;
 }
 
+.bpm-editor-info {
+  font-family: sans-serif;
+  font-size:18px;  
+}
+
 .bpm-menu {
   height: 50px;
   width: 100%;

Modified: projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/workspace-default.cfg
===================================================================
--- projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/workspace-default.cfg	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/resources/org/jboss/bpm/console/workspace-default.cfg	2009-04-16 13:31:50 UTC (rev 4566)
@@ -1,5 +1,5 @@
 org.jboss.bpm.console.client.v2.process.ProcessEditor
-org.jboss.bpm.console.client.task.TaskEditor
+#org.jboss.bpm.console.client.task.TaskEditor
 
 # not yet implemented in jBPM4
 #org.jboss.bpm.console.client.report.ReportEditor  
\ No newline at end of file




More information about the jbpm-commits mailing list
--- projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/LoginView.java	2009-04-16 13:09:58 UTC (rev 4565)
+++ projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/LoginView.java	2009-04-16 13:31:50 UTC (rev 4566)
@@ -51,8 +51,6 @@
 {
   public final static String NAME = "loginView";
 
-  private Controller controller;
-
   private ConsoleConfig config;
   private URLBuilder urlBuilder;
   private Authentication auth;
@@ -63,6 +61,7 @@
 
   public final static String[] KNOWN_ROLES = {"admin", "manager", "user"};
 
+  private Controller controller;
 
   public LoginView()
   {
@@ -149,10 +148,8 @@
                 // display main console
                 window.hide();
 
-                // assemble main view                
-                controller.handleEvent( new Event("loginSuccessful",
-                    new BootstrapEvent(auth, urlBuilder, config)) 
-                );
+                // assemble main layout                
+                new MainLayout(controller, auth, urlBuilder, config);
               }
 
               public void onLoginFailed(Request request, Throwable t)

Copied: projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainLayout.java (from rev 4556, projects/gwt-console/branches/hbraun/war/src/main/java/org/jboss/bpm/console/client/v2/MainView.java)
===================================================================